print("import: 'pptx'")
import pptx

print("import: 'pptx.chart'")
import pptx.chart

print("import: 'pptx.compat'")
import pptx.compat

print("import: 'pptx.dml'")
import pptx.dml

print("import: 'pptx.enum'")
import pptx.enum

print("import: 'pptx.opc'")
import pptx.opc

print("import: 'pptx.oxml'")
import pptx.oxml

print("import: 'pptx.oxml.chart'")
import pptx.oxml.chart

print("import: 'pptx.oxml.dml'")
import pptx.oxml.dml

print("import: 'pptx.oxml.shapes'")
import pptx.oxml.shapes

print("import: 'pptx.parts'")
import pptx.parts

print("import: 'pptx.shapes'")
import pptx.shapes

print("import: 'pptx.text'")
import pptx.text

